@@ -32,16 +32,21 @@ def builtin_input_handler(user_input: str, agent_: Any) -> Tuple[str, bool]:
     for tag in special_tags:
         # 优先处理特殊标记
         if tag == "Summary":
-            agent._summarize_and_clear_history()
-            return "", True
+            summary = agent._summarize_and_clear_history()
+            memory_tags_prompt = agent.memory_manager.prepare_memory_tags_prompt()
+            prompt = ""
+            if summary:
+                # 将摘要和记忆标签设置为新会话的初始提示
+                prompt = summary + "\n" + memory_tags_prompt
+            else:
+                # 即使没有摘要，也确保设置记忆标签作为新会话的初始提示
+                prompt = memory_tags_prompt
+            return prompt, True
         elif tag == "Clear":
             agent.clear()
             return "", True
         elif tag == "ToolUsage":
-            from jarvis.jarvis_tools.registry import ToolRegistry
-            from jarvis.jarvis_agent.prompt_builder import build_action_prompt
-            action_prompt = build_action_prompt(agent.output_handler) # type: ignore
-            agent.set_addon_prompt(action_prompt)
+            agent.set_addon_prompt(agent.get_tool_usage_prompt())
             return "", False
         elif tag == "ReloadConfig":
             from jarvis.jarvis_utils.utils import load_config
