@@ -3,16 +3,22 @@ import os
 import re
 import subprocess
 import tempfile
-from typing import Any, Dict, List
+import sys
+from typing import Any, Dict, List, Optional
+
+import typer
 
 from jarvis.jarvis_agent import Agent
 from jarvis.jarvis_code_analysis.checklists.loader import get_language_checklist
 from jarvis.jarvis_platform.registry import PlatformRegistry
 from jarvis.jarvis_tools.read_code import ReadCodeTool
+from jarvis.jarvis_utils.globals import get_agent, current_agent_name
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
 from jarvis.jarvis_utils.tag import ct, ot
 from jarvis.jarvis_utils.utils import init_env, is_context_overflow
 
+app = typer.Typer(help="自动代码审查工具")
+
 
 class CodeReviewTool:
     name = "code_review"
@@ -261,7 +267,9 @@ class CodeReviewTool:
         checklist = get_language_checklist(language)
         return checklist if checklist else ""
 
-    def execute(self, args: Dict[str, Any]) -> Dict[str, Any]:
+    def execute(
+        self, args: Dict[str, Any], agent: Optional["Agent"] = None
+    ) -> Dict[str, Any]:
         try:
             review_type = args.get("review_type", "current").strip()
             root_dir = args.get("root_dir", ".")
@@ -292,7 +300,11 @@ class CodeReviewTool:
 
                     # Execute git command and get diff output
                     diff_output = subprocess.check_output(
-                        diff_cmd, shell=True, text=True
+                        diff_cmd,
+                        shell=True,
+                        text=True,
+                        encoding="utf-8",
+                        errors="replace",
                     )
                     if not diff_output:
                         return {
@@ -302,11 +314,13 @@ class CodeReviewTool:
                         }
 
                     # Extract changed files using git command
-                    files_cmd = f"git show --name-only --pretty=format: {commit_sha} | grep -v '^$'"
+                    # Use git show with proper formatting to avoid needing grep
+                    files_cmd = f"git show --name-only --pretty=format: {commit_sha}"
                     try:
                         files_output = subprocess.check_output(
                             files_cmd, shell=True, text=True
                         )
+                        # Filter out empty lines without using grep
                         file_paths = [
                             f.strip() for f in files_output.split("\n") if f.strip()
                         ]
@@ -329,7 +343,11 @@ class CodeReviewTool:
 
                     # Execute git command and get diff output
                     diff_output = subprocess.check_output(
-                        diff_cmd, shell=True, text=True
+                        diff_cmd,
+                        shell=True,
+                        text=True,
+                        encoding="utf-8",
+                        errors="replace",
                     )
                     if not diff_output:
                         return {
@@ -371,7 +389,11 @@ class CodeReviewTool:
 
                     # Execute git command and get diff output
                     diff_output = subprocess.check_output(
-                        diff_cmd, shell=True, text=True
+                        diff_cmd,
+                        shell=True,
+                        text=True,
+                        encoding="utf-8",
+                        errors="replace",
                     )
                     if not diff_output:
                         return {
@@ -570,6 +592,46 @@ class CodeReviewTool:
 
                 tool_registry = ToolRegistry()
                 tool_registry.dont_use_tools(["code_review"])
+
+                # Get llm_type and model_group from args
+                llm_type = args.get("llm_type", "normal")
+                model_group = args.get("model_group")
+
+                # Get platform and model based on llm_type and model_group
+                from jarvis.jarvis_utils.config import (
+                    get_normal_platform_name,
+                    get_normal_model_name,
+                    get_thinking_platform_name,
+                    get_thinking_model_name,
+                )
+
+                if llm_type == "thinking":
+                    platform_name = get_thinking_platform_name(model_group)
+                    model_name = get_thinking_model_name(model_group)
+                else:
+                    platform_name = get_normal_platform_name(model_group)
+                    model_name = get_normal_model_name(model_group)
+
+                # If no explicit parameters, try to get from existing agent
+                calling_agent = agent or get_agent(current_agent_name)
+                if (
+                    not platform_name
+                    and calling_agent
+                    and hasattr(calling_agent, "model")
+                    and calling_agent.model
+                ):
+                    platform_name = calling_agent.model.platform_name()
+                    model_name = calling_agent.model.name()
+
+                # Create a new platform instance
+                review_model = None
+                if platform_name:
+                    review_model = PlatformRegistry().create_platform(platform_name)
+                    if review_model and model_name:
+                        review_model.set_model_name(model_name)
+                        if model_group:
+                            review_model.model_group = model_group
+
                 agent = Agent(
                     system_prompt=system_prompt,
                     name="Code Review Agent",
@@ -637,11 +699,15 @@ class CodeReviewTool:
 {ot("REPORT")}
 [在此处插入完整MARKDOWN格式的审查报告]
 {ct("REPORT")}""",
-                    output_handler=[tool_registry],
+                    output_handler=[tool_registry],  # type: ignore
                     llm_type="thinking",
                     auto_complete=False,
                 )
 
+                # Replace the agent's model with our custom platform instance
+                if review_model:
+                    agent.model = review_model
+
                 # Determine if we need to split the diff due to size
                 max_diff_size = 100 * 1024 * 1024  # Limit to 100MB
 
@@ -675,7 +741,9 @@ class CodeReviewTool:
 
                 try:
                     # Check if content is too large
-                    is_large_content = is_context_overflow(diff_output)
+                    is_large_content = is_context_overflow(
+                        diff_output, review_model.model_group if review_model else None
+                    )
 
                     # Upload the file to the agent's model
                     if is_large_content:
@@ -751,60 +819,144 @@ def extract_code_report(result: str) -> str:
     return result
 
 
-def main():
-    """CLI entry point"""
-    import argparse
-
-    init_env("欢迎使用 Jarvis-CodeReview，您的代码审查助手已准备就绪！")
-
-    parser = argparse.ArgumentParser(description="Autonomous code review tool")
-    subparsers = parser.add_subparsers(dest="type")
-
-    # Commit subcommand
-    commit_parser = subparsers.add_parser("commit", help="Review specific commit")
-    commit_parser.add_argument("commit", help="Commit SHA to review")
-
-    # Current subcommand
-    subparsers.add_parser("current", help="Review current changes")
-
-    # Range subcommand
-    range_parser = subparsers.add_parser("range", help="Review commit range")
-    range_parser.add_argument("start_commit", help="Start commit SHA")
-    range_parser.add_argument("end_commit", help="End commit SHA")
-
-    # File subcommand
-    file_parser = subparsers.add_parser("file", help="Review specific file")
-    file_parser.add_argument("file", help="File path to review")
-
-    # Common arguments
-    parser.add_argument(
-        "--root-dir", type=str, help="Root directory of the codebase", default="."
-    )
-
-    # Set default subcommand to 'current'
-    parser.set_defaults(type="current")
-    args = parser.parse_args()
-
+@app.command("commit")
+def review_commit(
+    commit: str = typer.Argument(..., help="要审查的提交SHA"),
+    root_dir: str = typer.Option(".", "--root-dir", help="代码库根目录路径"),
+    llm_type: str = typer.Option(
+        "normal",
+        "-t",
+        "--llm-type",
+        help="使用的LLM类型，可选值：'normal'（普通）或 'thinking'（思考模式）",
+    ),
+    model_group: Optional[str] = typer.Option(
+        None, "-g", "--llm-group", help="使用的模型组，覆盖配置文件中的设置"
+    ),
+):
+    """审查指定的提交"""
     tool = CodeReviewTool()
-    tool_args = {"review_type": args.type, "root_dir": args.root_dir}
-    if args.type == "commit":
-        tool_args["commit_sha"] = args.commit
-    elif args.type == "range":
-        tool_args["start_commit"] = args.start_commit
-        tool_args["end_commit"] = args.end_commit
-    elif args.type == "file":
-        tool_args["file_path"] = args.file
-
+    tool_args = {
+        "review_type": "commit",
+        "commit_sha": commit,
+        "root_dir": root_dir,
+        "llm_type": llm_type,
+        "model_group": model_group,
+    }
     result = tool.execute(tool_args)
-
     if result["success"]:
         PrettyOutput.section("自动代码审查结果:", OutputType.SUCCESS)
         report = extract_code_report(result["stdout"])
         PrettyOutput.print(report, OutputType.SUCCESS, lang="markdown")
-
     else:
         PrettyOutput.print(result["stderr"], OutputType.WARNING)
 
 
+@app.command("current")
+def review_current(
+    root_dir: str = typer.Option(".", "--root-dir", help="代码库根目录路径"),
+    llm_type: str = typer.Option(
+        "normal",
+        "-t",
+        "--llm-type",
+        help="使用的LLM类型，可选值：'normal'（普通）或 'thinking'（思考模式）",
+    ),
+    model_group: Optional[str] = typer.Option(
+        None, "-g", "--llm-group", help="使用的模型组，覆盖配置文件中的设置"
+    ),
+):
+    """审查当前的变更"""
+    tool = CodeReviewTool()
+    tool_args = {
+        "review_type": "current",
+        "root_dir": root_dir,
+        "llm_type": llm_type,
+        "model_group": model_group,
+    }
+    result = tool.execute(tool_args)
+    if result["success"]:
+        PrettyOutput.section("自动代码审查结果:", OutputType.SUCCESS)
+        report = extract_code_report(result["stdout"])
+        PrettyOutput.print(report, OutputType.SUCCESS, lang="markdown")
+    else:
+        PrettyOutput.print(result["stderr"], OutputType.WARNING)
+
+
+@app.command("range")
+def review_range(
+    start_commit: str = typer.Argument(..., help="起始提交SHA"),
+    end_commit: str = typer.Argument(..., help="结束提交SHA"),
+    root_dir: str = typer.Option(".", "--root-dir", help="代码库根目录路径"),
+    llm_type: str = typer.Option(
+        "normal",
+        "-t",
+        "--llm-type",
+        help="使用的LLM类型，可选值：'normal'（普通）或 'thinking'（思考模式）",
+    ),
+    model_group: Optional[str] = typer.Option(
+        None, "-g", "--llm-group", help="使用的模型组，覆盖配置文件中的设置"
+    ),
+):
+    """审查提交范围"""
+    tool = CodeReviewTool()
+    tool_args = {
+        "review_type": "range",
+        "start_commit": start_commit,
+        "end_commit": end_commit,
+        "root_dir": root_dir,
+        "llm_type": llm_type,
+        "model_group": model_group,
+    }
+    result = tool.execute(tool_args)
+    if result["success"]:
+        PrettyOutput.section("自动代码审查结果:", OutputType.SUCCESS)
+        report = extract_code_report(result["stdout"])
+        PrettyOutput.print(report, OutputType.SUCCESS, lang="markdown")
+    else:
+        PrettyOutput.print(result["stderr"], OutputType.WARNING)
+
+
+@app.command("file")
+def review_file(
+    file: str = typer.Argument(..., help="要审查的文件路径"),
+    root_dir: str = typer.Option(".", "--root-dir", help="代码库根目录路径"),
+    llm_type: str = typer.Option(
+        "normal",
+        "-t",
+        "--llm-type",
+        help="使用的LLM类型，可选值：'normal'（普通）或 'thinking'（思考模式）",
+    ),
+    model_group: Optional[str] = typer.Option(
+        None, "-g", "--llm-group", help="使用的模型组，覆盖配置文件中的设置"
+    ),
+):
+    """审查指定的文件"""
+    tool = CodeReviewTool()
+    tool_args = {
+        "review_type": "file",
+        "file_path": file,
+        "root_dir": root_dir,
+        "llm_type": llm_type,
+        "model_group": model_group,
+    }
+    result = tool.execute(tool_args)
+    if result["success"]:
+        PrettyOutput.section("自动代码审查结果:", OutputType.SUCCESS)
+        report = extract_code_report(result["stdout"])
+        PrettyOutput.print(report, OutputType.SUCCESS, lang="markdown")
+    else:
+        PrettyOutput.print(result["stderr"], OutputType.WARNING)
+
+
+def cli():
+    """Typer application entry point"""
+    init_env("欢迎使用 Jarvis-CodeReview，您的代码审查助手已准备就绪！")
+    app()
+
+
+def main():
+    """Main entry point for the script"""
+    cli()
+
+
 if __name__ == "__main__":
     main()
