@@ -8,21 +8,29 @@
 - 列出所有方法论
 """
 
-import argparse
 import hashlib
 import json
 import os
+import sys
+from typing import Optional
 
+import typer
 import yaml  # type: ignore
-from yaspin import yaspin  # type: ignore
 
 from jarvis.jarvis_platform.registry import PlatformRegistry
-from jarvis.jarvis_utils.methodology import (_get_methodology_directory,
-                                             _load_all_methodologies)
+from jarvis.jarvis_utils.methodology import (
+    _get_methodology_directory,
+    _load_all_methodologies,
+)
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
 
+app = typer.Typer(help="方法论管理工具")
 
-def import_methodology(input_file):
+
+@app.command("import")
+def import_methodology(
+    input_file: str = typer.Argument(..., help="要导入的方法论文件路径")
+):
     """导入方法论文件（合并策略）"""
     try:
         # 加载现有方法论
@@ -55,9 +63,13 @@ def import_methodology(input_file):
         )
     except (json.JSONDecodeError, OSError) as e:
         PrettyOutput.print(f"导入失败: {str(e)}", OutputType.ERROR)
+        raise typer.Exit(code=1)
 
 
-def export_methodology(output_file):
+@app.command("export")
+def export_methodology(
+    output_file: str = typer.Argument(..., help="导出文件路径")
+):
     """导出当前方法论到单个文件"""
     try:
         methodologies = _load_all_methodologies()
@@ -71,8 +83,10 @@ def export_methodology(output_file):
         )
     except (OSError, TypeError) as e:
         PrettyOutput.print(f"导出失败: {str(e)}", OutputType.ERROR)
+        raise typer.Exit(code=1)
 
 
+@app.command("list")
 def list_methodologies():
     """列出所有方法论"""
     try:
@@ -87,9 +101,13 @@ def list_methodologies():
             PrettyOutput.print(f"{i}. {problem_type}", OutputType.INFO)
     except (OSError, json.JSONDecodeError) as e:
         PrettyOutput.print(f"列出方法论失败: {str(e)}", OutputType.ERROR)
+        raise typer.Exit(code=1)
 
 
-def extract_methodology(input_file):
+@app.command("extract")
+def extract_methodology(
+    input_file: str = typer.Argument(..., help="要提取方法论的文本文件路径")
+):
     """从文本文件中提取方法论"""
     try:
         # 读取文本文件内容
@@ -128,46 +146,40 @@ def extract_methodology(input_file):
 """
 
         # 调用大模型平台提取方法论
-        with yaspin(text="正在提取方法论...", color="yellow") as spinner:
-            try:
-                response = platform.chat_until_success(prompt)
-            except Exception as e:
-                spinner.text = "提取失败"
-                spinner.fail("❌")
-                PrettyOutput.print(f"提取方法论失败: {str(e)}", OutputType.ERROR)
-                return
+        print("📥 正在提取方法论...")
+        try:
+            response = platform.chat_until_success(prompt)
+        except Exception as e:
+            print("❌ 提取失败")
+            PrettyOutput.print(f"提取方法论失败: {str(e)}", OutputType.ERROR)
+            raise typer.Exit(code=1)
 
-            # 提取YAML部分
-            methodologies_start = response.find("<methodologies>") + len(
-                "<methodologies>"
+        # 提取YAML部分
+        methodologies_start = response.find("<methodologies>") + len("<methodologies>")
+        methodologies_end = response.find("</methodologies>")
+        if methodologies_start == -1 or methodologies_end == -1:
+            print("❌ 响应格式无效")
+            PrettyOutput.print(
+                "大模型未返回有效的<methodologies>格式", OutputType.ERROR
             )
-            methodologies_end = response.find("</methodologies>")
-            if methodologies_start == -1 or methodologies_end == -1:
-                spinner.text = "响应格式无效"
-                spinner.fail("❌")
-                PrettyOutput.print(
-                    "大模型未返回有效的<methodologies>格式", OutputType.ERROR
-                )
-                return
+            raise typer.Exit(code=1)
 
-            yaml_content = response[methodologies_start:methodologies_end].strip()
+        yaml_content = response[methodologies_start:methodologies_end].strip()
 
-            try:
-                data = yaml.safe_load(yaml_content)
-                extracted_methodologies = {
-                    item["problem_type"]: item["content"] for item in data
-                }
-            except (yaml.YAMLError, KeyError, TypeError) as e:
-                spinner.text = "YAML解析失败"
-                spinner.fail("❌")
-                PrettyOutput.print(f"YAML解析错误: {str(e)}", OutputType.ERROR)
-                return
+        try:
+            data = yaml.safe_load(yaml_content)
+            extracted_methodologies = {
+                item["problem_type"]: item["content"] for item in data
+            }
+        except (yaml.YAMLError, KeyError, TypeError) as e:
+            print("❌ YAML解析失败")
+            PrettyOutput.print(f"YAML解析错误: {str(e)}", OutputType.ERROR)
+            raise typer.Exit(code=1)
 
-            if not extracted_methodologies:
-                spinner.text = "未提取到有效方法论"
-                spinner.fail("❌")
-                return
-            spinner.ok("✅")
+        if not extracted_methodologies:
+            print("❌ 未提取到有效方法论")
+            return
+        print("✅ 提取到有效方法论")
 
         # 加载现有方法论
         existing_methodologies = _load_all_methodologies()
@@ -195,9 +207,11 @@ def extract_methodology(input_file):
         )
     except Exception as e:
         PrettyOutput.print(f"提取失败: {str(e)}", OutputType.ERROR)
+        raise typer.Exit(code=1)
 
 
-def extract_methodology_from_url(url):
+@app.command("extract-url")
+def extract_methodology_from_url(url: str = typer.Argument(..., help="要提取方法论的URL")):
     """从URL提取方法论"""
     try:
         # 获取平台实例
@@ -233,46 +247,40 @@ def extract_methodology_from_url(url):
 6. 内容字段使用|保留多行格式
 """
         # 调用大模型平台提取方法论
-        with yaspin(text="正在从URL提取方法论...", color="yellow") as spinner:
-            try:
-                response = platform.chat_until_success(prompt)
-            except Exception as e:
-                spinner.text = "提取失败"
-                spinner.fail("❌")
-                PrettyOutput.print(f"提取方法论失败: {str(e)}", OutputType.ERROR)
-                return
+        print("📥 正在从URL提取方法论...")
+        try:
+            response = platform.chat_until_success(prompt)
+        except Exception as e:
+            print("❌ 提取失败")
+            PrettyOutput.print(f"提取方法论失败: {str(e)}", OutputType.ERROR)
+            raise typer.Exit(code=1)
 
-            # 提取YAML部分
-            methodologies_start = response.find("<methodologies>") + len(
-                "<methodologies>"
+        # 提取YAML部分
+        methodologies_start = response.find("<methodologies>") + len("<methodologies>")
+        methodologies_end = response.find("</methodologies>")
+        if methodologies_start == -1 or methodologies_end == -1:
+            print("❌ 响应格式无效")
+            PrettyOutput.print(
+                "大模型未返回有效的<methodologies>格式", OutputType.ERROR
             )
-            methodologies_end = response.find("</methodologies>")
-            if methodologies_start == -1 or methodologies_end == -1:
-                spinner.text = "响应格式无效"
-                spinner.fail("❌")
-                PrettyOutput.print(
-                    "大模型未返回有效的<methodologies>格式", OutputType.ERROR
-                )
-                return
+            raise typer.Exit(code=1)
 
-            yaml_content = response[methodologies_start:methodologies_end].strip()
+        yaml_content = response[methodologies_start:methodologies_end].strip()
 
-            try:
-                data = yaml.safe_load(yaml_content)
-                extracted_methodologies = {
-                    item["problem_type"]: item["content"] for item in data
-                }
-            except (yaml.YAMLError, KeyError, TypeError) as e:
-                spinner.text = "YAML解析失败"
-                spinner.fail("❌")
-                PrettyOutput.print(f"YAML解析错误: {str(e)}", OutputType.ERROR)
-                return
+        try:
+            data = yaml.safe_load(yaml_content)
+            extracted_methodologies = {
+                item["problem_type"]: item["content"] for item in data
+            }
+        except (yaml.YAMLError, KeyError, TypeError) as e:
+            print("❌ YAML解析失败")
+            PrettyOutput.print(f"YAML解析错误: {str(e)}", OutputType.ERROR)
+            raise typer.Exit(code=1)
 
-            if not extracted_methodologies:
-                spinner.text = "未提取到有效方法论"
-                spinner.fail("❌")
-                return
-            spinner.ok("✅")
+        if not extracted_methodologies:
+            print("❌ 未提取到有效方法论")
+            return
+        print("✅ 提取到有效方法论")
 
         # 加载现有方法论
         existing_methodologies = _load_all_methodologies()
@@ -300,46 +308,12 @@ def extract_methodology_from_url(url):
         )
     except Exception as e:
         PrettyOutput.print(f"从URL提取失败: {str(e)}", OutputType.ERROR)
+        raise typer.Exit(code=1)
 
 
-def main():
-    """方法论管理工具主函数"""
-    parser = argparse.ArgumentParser(description="方法论管理工具")
-    subparsers = parser.add_subparsers(dest="command", required=True)
-
-    # import命令
-    import_parser = subparsers.add_parser("import", help="导入方法论文件（合并策略）")
-    import_parser.add_argument("input_file", type=str, help="要导入的方法论文件路径")
-
-    # export命令
-    export_parser = subparsers.add_parser("export", help="导出当前方法论到单个文件")
-    export_parser.add_argument("output_file", type=str, help="导出文件路径")
-
-    # list命令
-    subparsers.add_parser("list", help="列出所有方法论")
-
-    # extract命令
-    extract_parser = subparsers.add_parser("extract", help="从文本文件中提取方法论")
-    extract_parser.add_argument(
-        "input_file", type=str, help="要提取方法论的文本文件路径"
-    )
-
-    # extract-url命令
-    extract_url_parser = subparsers.add_parser("extract-url", help="从URL提取方法论")
-    extract_url_parser.add_argument("url", type=str, help="要提取方法论的URL")
-
-    args = parser.parse_args()
-
-    if args.command == "import":
-        import_methodology(args.input_file)
-    elif args.command == "export":
-        export_methodology(args.output_file)
-    elif args.command == "list":
-        list_methodologies()
-    elif args.command == "extract":
-        extract_methodology(args.input_file)
-    elif args.command == "extract-url":
-        extract_methodology_from_url(args.url)
+def main() -> None:
+    """Application entry point"""
+    app()
 
 
 if __name__ == "__main__":
