@@ -156,39 +156,24 @@ class KimiModel(BasePlatform):
                 sleep_time=5,
             )
 
-            response_data = b""
-
             # 处理流式响应
-            for chunk in response_stream:
-                response_data += chunk
-
-                # 尝试解析SSE格式的数据
-                try:
-                    # 查找完整的数据行
-                    lines = response_data.decode("utf-8").split("\n")
-                    response_data = b""  # 重置缓冲区
-
-                    for line in lines:
-                        if not line.strip():
-                            continue
-
-                        # SSE格式的行通常以"data: "开头
-                        if line.startswith("data: "):
-                            try:
-                                data = json.loads(line[6:])
-                                if data.get("event") == "resp":
-                                    status = data.get("file_info", {}).get("status")
-                                    if status == "parsed":
-                                        return True
-                                    elif status == "failed":
-                                        return False
-                            except json.JSONDecodeError:
-                                continue
-
-                except UnicodeDecodeError:
-                    # 如果解码失败，继续累积数据
+            for line in response_stream:
+                if not line.strip():
                     continue
 
+                # SSE格式的行通常以"data: "开头
+                if line.startswith("data: "):
+                    try:
+                        data = json.loads(line[6:])
+                        if data.get("event") == "resp":
+                            status = data.get("file_info", {}).get("status")
+                            if status == "parsed":
+                                return True
+                            elif status == "failed":
+                                return False
+                    except json.JSONDecodeError:
+                        continue
+
             retry_count += 1
             time.sleep(1)
 
@@ -299,40 +284,25 @@ class KimiModel(BasePlatform):
                 sleep_time=5,
             )
 
-            response_data = b""
-
             # 处理流式响应
-            for chunk in response_stream:
-                response_data += chunk
-
-                # 尝试解析SSE格式的数据
-                try:
-                    # 查找完整的数据行
-                    lines = response_data.decode("utf-8").split("\n")
-                    response_data = b""  # 重置缓冲区
-
-                    for line in lines:
-                        if not line.strip():
-                            continue
-
-                        # SSE格式的行通常以"data: "开头
-                        if line.startswith("data: "):
-                            try:
-                                data = json.loads(line[6:])
-                                event = data.get("event")
-
-                                if event == "cmpl":
-                                    # 处理补全文本
-                                    text = data.get("text", "")
-                                    if text:
-                                        yield text
-                            except json.JSONDecodeError:
-                                continue
-
-                except UnicodeDecodeError:
-                    # 如果解码失败，继续累积数据
+            for line in response_stream:
+                if not line.strip():
                     continue
 
+                # SSE格式的行通常以"data: "开头
+                if line.startswith("data: "):
+                    try:
+                        data = json.loads(line[6:])
+                        event = data.get("event")
+
+                        if event == "cmpl":
+                            # 处理补全文本
+                            text = data.get("text", "")
+                            if text:
+                                yield text
+                    except json.JSONDecodeError:
+                        continue
+
             return None
 
         except Exception as e:
@@ -425,3 +395,33 @@ class KimiModel(BasePlatform):
     def support_web(self) -> bool:
         """Kimi平台支持web功能"""
         return True
+
+    @classmethod
+    def get_required_env_keys(cls) -> List[str]:
+        """
+        获取Kimi平台所需的环境变量键列表
+
+        返回:
+            List[str]: 环境变量键的列表
+        """
+        return ["KIMI_API_KEY"]
+
+    @classmethod
+    def get_env_config_guide(cls) -> Dict[str, str]:
+        """
+        获取环境变量配置指导
+
+        返回:
+            Dict[str, str]: 环境变量名到配置指导的映射
+        """
+        return {
+            "KIMI_API_KEY": (
+                "1. 登录 Kimi 网页版: https://kimi.moonshot.cn/\n"
+                "2. 打开浏览器开发者工具 (F12)\n"
+                '3. 切换到"网络"(Network)标签页\n'
+                "4. 在 Kimi 中发送一条消息\n"
+                "5. 找到 stream 请求\n"
+                '6. 在"请求标头"中找到 authorization 字段\n'
+                "7. 复制 Bearer 后面的 API Key 部分"
+            )
+        }
