@@ -5,12 +5,10 @@ import time
 import uuid
 from typing import Any, Dict, Generator, List, Tuple
 
-import requests
-from yaspin import yaspin
-from yaspin.spinners import Spinners
-
 from jarvis.jarvis_platform.base import BasePlatform
+from jarvis.jarvis_utils import http
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
+from jarvis.jarvis_utils.tag import ot, ct
 from jarvis.jarvis_utils.utils import while_success
 
 
@@ -20,8 +18,6 @@ class TongyiPlatform(BasePlatform):
     # Supported image formats
     IMAGE_EXTENSIONS = {".jpg", ".jpeg", ".png", ".gif", ".webp", ".bmp", ".tiff"}
 
-    platform_name = "tongyi"
-
     def __init__(self):
         """Initialize Tongyi platform"""
         super().__init__()
@@ -86,10 +82,10 @@ class TongyiPlatform(BasePlatform):
                 "contentType": "text",
                 "role": "user",
                 "ext": {
-                    "searchType": "",
+                    "searchType": "depth" if self.web else "",
                     "pptGenerate": False,
-                    "deepThink": False,
-                    "deepResearch": False,
+                    "deepThink": self.model_name == "Thinking",
+                    "deepResearch": self.model_name == "Deep-Research",
                 },
             }
         ]
@@ -103,10 +99,10 @@ class TongyiPlatform(BasePlatform):
                     "contentType": "text",
                     "role": "system",
                     "ext": {
-                        "searchType": "",
+                        "searchType": "depth" if self.web else "",
                         "pptGenerate": False,
-                        "deepThink": False,
-                        "deepResearch": False,
+                        "deepThink": self.model_name == "Thinking",
+                        "deepResearch": self.model_name == "Deep-Research",
                     },
                 },
             )
@@ -145,13 +141,13 @@ class TongyiPlatform(BasePlatform):
             "parentMsgId": self.msg_id,
             "params": {
                 "agentId": "",
-                "searchType": "",
+                "searchType": "depth" if self.web else "",
                 "pptGenerate": False,
                 "bizScene": "code_chat" if self.model_name == "Code-Chat" else "",
                 "bizSceneInfo": {},
                 "specifiedModel": "",
-                "deepThink": True if self.model_name == "Thinking" else False,
-                "deepResearch": False,
+                "deepThink": self.model_name == "Thinking",
+                "deepResearch": self.model_name == "Deep-Research",
                 "fileUploadBatchId": (
                     self.uploaded_file_info[0]["batchId"]
                     if self.uploaded_file_info
@@ -162,88 +158,79 @@ class TongyiPlatform(BasePlatform):
         }
 
         try:
-            response = while_success(
-                lambda: requests.post(url, headers=headers, json=payload, stream=True),
+            # 使用新的stream_post接口发送消息请求，获取流式响应
+            response_stream = while_success(
+                lambda: http.stream_post(url, headers=headers, json=payload),
                 sleep_time=5,
             )
-            if response.status_code != 200:
-                raise Exception(f"HTTP {response.status_code}: {response.text}")
+
             msg_id = ""
             session_id = ""
             thinking_content = ""
             text_content = ""
             in_thinking = False
-            for line in response.iter_lines():
-                if not line:
-                    continue
-                line_str = line.decode("utf-8")
-                if not line_str.startswith("data: "):
+
+            # 处理流式响应
+            for line in response_stream:
+                if not line.strip():
                     continue
 
-                try:
-                    data = json.loads(line_str[6:])
-                    # 记录消息ID和会话ID
-                    if "msgId" in data:
-                        msg_id = data["msgId"]
-                    if "sessionId" in data:
-                        session_id = data["sessionId"]
+                # SSE格式的行通常以"data: "开头
+                if line.startswith("data: "):
+                    try:
+                        data = json.loads(line[6:])
+                        # 记录消息ID和会话ID
+                        if "msgId" in data:
+                            msg_id = data["msgId"]
+                        if "sessionId" in data:
+                            session_id = data["sessionId"]
 
-                    if "contents" in data and len(data["contents"]) > 0:
-                        for content in data["contents"]:
-                            if content.get("contentType") == "think":
-                                if not in_thinking:
-                                    yield "<think>\n\n"
-                                    in_thinking = True
-                                if content.get("incremental"):
-                                    tmp_content = json.loads(content.get("content"))[
-                                        "content"
-                                    ]
-                                    thinking_content += tmp_content
-                                    yield tmp_content
-                                else:
-                                    tmp_content = json.loads(content.get("content"))[
-                                        "content"
-                                    ]
-                                    if len(thinking_content) < len(tmp_content):
-                                        yield tmp_content[len(thinking_content) :]
-                                        thinking_content = tmp_content
+                        if "contents" in data and len(data["contents"]) > 0:
+                            for content in data["contents"]:
+                                if content.get("contentType") == "think":
+                                    if not in_thinking:
+                                        yield f"{ot('think')}\n\n"
+                                        in_thinking = True
+                                    if content.get("incremental"):
+                                        tmp_content = json.loads(
+                                            content.get("content")
+                                        )["content"]
+                                        thinking_content += tmp_content
+                                        yield tmp_content
                                     else:
-                                        # thinking_content = "aaa</thi"
-                                        # tmp_content = "aaa"
-                                        # 应该yield nk>
-                                        # print("\n")
-                                        # print(len(thinking_content))
-                                        # print(len(tmp_content))
-                                        # print("--------------------------------")
-                                        # print(thinking_content)
-                                        # print("--------------------------------")
-                                        # print(tmp_content)
-                                        # print("--------------------------------")
-                                        yield "\r\n</think>\n"[
-                                            len(thinking_content) - len(tmp_content) :
-                                        ]
-                                        thinking_content = tmp_content
-                                    in_thinking = False
-                            elif content.get("contentType") == "text":
-                                if in_thinking:
-                                    continue
-                                if content.get("incremental"):
-                                    tmp_content = content.get("content")
-                                    text_content += tmp_content
-                                    yield tmp_content
-                                else:
-                                    tmp_content = content.get("content")
-                                    if len(text_content) < len(tmp_content):
-                                        yield tmp_content[len(text_content) :]
-                                        text_content = tmp_content
+                                        tmp_content = json.loads(
+                                            content.get("content")
+                                        )["content"]
+                                        if len(thinking_content) < len(tmp_content):
+                                            yield tmp_content[len(thinking_content) :]
+                                            thinking_content = tmp_content
+                                        else:
+                                            yield f"\r\n{ct('think')}\n"[
+                                                len(thinking_content)
+                                                - len(tmp_content) :
+                                            ]
+                                            thinking_content = tmp_content
+                                        in_thinking = False
+                                elif content.get("contentType") == "text":
+                                    if in_thinking:
+                                        continue
+                                    if content.get("incremental"):
+                                        tmp_content = content.get("content")
+                                        text_content += tmp_content
+                                        yield tmp_content
+                                    else:
+                                        tmp_content = content.get("content")
+                                        if len(text_content) < len(tmp_content):
+                                            yield tmp_content[len(text_content) :]
+                                            text_content = tmp_content
 
-                except json.JSONDecodeError:
-                    continue
+                    except json.JSONDecodeError:
+                        continue
 
             self.msg_id = msg_id
             self.session_id = session_id
 
-            return None
+            return
 
         except Exception as e:
             raise Exception(f"Chat failed: {str(e)}")
@@ -256,11 +243,11 @@ class TongyiPlatform(BasePlatform):
         """
         url = "https://api.tongyi.com/dialog/uploadToken"
         headers = self._get_base_headers()
-        payload = {}
+        payload: Dict[str, Any] = {}
 
         try:
             response = while_success(
-                lambda: requests.post(url, headers=headers, json=payload), sleep_time=5
+                lambda: http.post(url, headers=headers, json=payload), sleep_time=5
             )
             if response.status_code != 200:
                 raise Exception(f"HTTP {response.status_code}: {response.text}")
@@ -289,140 +276,124 @@ class TongyiPlatform(BasePlatform):
 
             for file_path in file_list:
                 file_name = os.path.basename(file_path)
-                with yaspin(Spinners.dots, text=f"上传文件 {file_name}") as spinner:
-                    try:
-                        if not os.path.exists(file_path):
-                            spinner.text = f"文件不存在: {file_path}"
-                            spinner.fail("❌")
-                            return False
-
-                        # Get file name and content type
-                        content_type = self._get_content_type(file_path)
-
-                        spinner.text = f"准备上传文件: {file_name}"
-
-                        # Prepare form data
-                        form_data = {
-                            "OSSAccessKeyId": upload_token["accessId"],
-                            "policy": upload_token["policy"],
-                            "signature": upload_token["signature"],
-                            "key": f"{upload_token['dir']}{file_name}",
-                            "dir": upload_token["dir"],
-                            "success_action_status": "200",
-                        }
-
-                        # Prepare files
-                        files = {
-                            "file": (file_name, open(file_path, "rb"), content_type)
-                        }
-
-                        spinner.text = f"正在上传文件: {file_name}"
-
-                        # Upload file
-                        response = requests.post(
-                            upload_token["host"], data=form_data, files=files
-                        )
-
-                        if response.status_code != 200:
-                            spinner.text = (
-                                f"上传失败 {file_name}: HTTP {response.status_code}"
-                            )
-                            spinner.fail("❌")
-                            return False
-
-                        # Determine file type based on extension
-                        file_ext = os.path.splitext(file_path)[1].lower()
-                        is_image = file_ext in self.IMAGE_EXTENSIONS
-
-                        uploaded_files.append(
-                            {
-                                "fileKey": file_name,
-                                "fileType": "image" if is_image else "file",
-                                "dir": upload_token["dir"],
-                            }
-                        )
-
-                        spinner.text = f"获取下载链接: {file_name}"
-
-                        # Get download links for uploaded files
-                        url = "https://api.tongyi.com/dialog/downloadLink/batch"
-                        headers = self._get_base_headers()
-                        payload = {
-                            "fileKeys": [f["fileKey"] for f in uploaded_files],
-                            "fileType": (
-                                "image"
-                                if any(f["fileType"] == "image" for f in uploaded_files)
-                                else "file"
-                            ),
-                            "dir": upload_token["dir"],
-                        }
-
-                        response = requests.post(url, headers=headers, json=payload)
-                        if response.status_code != 200:
-                            spinner.text = (
-                                f"获取下载链接失败: HTTP {response.status_code}"
-                            )
-                            spinner.fail("❌")
-                            return False
-
-                        result = response.json()
-                        if not result.get("success"):
-                            spinner.text = f"获取下载链接失败: {result.get('errorMsg')}"
-                            spinner.fail("❌")
-                            return False
-
-                        # Add files to chat
-                        self.uploaded_file_info = result.get("data", {}).get(
-                            "results", []
-                        )
-                        for file_info in self.uploaded_file_info:
-                            spinner.text = f"添加文件到对话: {file_name}"
-                            add_url = (
-                                "https://api.tongyi.com/assistant/api/chat/file/add"
-                            )
-                            add_payload = {
-                                "workSource": "chat",
-                                "terminal": "web",
-                                "workCode": "0",
-                                "channel": "home",
-                                "workType": "file",
-                                "module": "uploadhistory",
-                                "workName": file_info["fileKey"],
-                                "workId": file_info["docId"],
-                                "workResourcePath": file_info["url"],
-                                "sessionId": "",
-                                "batchId": str(uuid.uuid4()).replace("-", "")[
-                                    :32
-                                ],  # Generate random batchId
-                                "fileSize": os.path.getsize(file_path),
-                            }
-
-                            add_response = requests.post(
-                                add_url, headers=headers, json=add_payload
-                            )
-                            if add_response.status_code != 200:
-                                spinner.text = f"添加文件到对话失败: HTTP {add_response.status_code}"
-                                spinner.fail("❌")
-                                continue
-
-                            add_result = add_response.json()
-                            if not add_result.get("success"):
-                                spinner.text = (
-                                    f"添加文件到对话失败: {add_result.get('errorMsg')}"
-                                )
-                                spinner.fail("❌")
-                                continue
-
-                            file_info.update(add_result.get("data", {}))
-
-                        spinner.text = f"文件 {file_name} 上传成功"
-                        spinner.ok("✅")
-                        time.sleep(1)  # 短暂暂停以便用户看到成功状态
-
-                    except Exception as e:
-                        spinner.text = f"上传文件 {file_name} 时出错: {str(e)}"
-                        spinner.fail("❌")
+                print(f"🔍 上传文件 {file_name}")
+                try:
+                    if not os.path.exists(file_path):
+                        print(f"❌ 文件不存在: {file_path}")
                         return False
+
+                    # Get file name and content type
+                    content_type = self._get_content_type(file_path)
+
+                    print(f"🔍 准备上传文件: {file_name}")
+
+                    # Prepare form data
+                    form_data = {
+                        "OSSAccessKeyId": upload_token["accessId"],
+                        "policy": upload_token["policy"],
+                        "signature": upload_token["signature"],
+                        "key": f"{upload_token['dir']}{file_name}",
+                        "dir": upload_token["dir"],
+                        "success_action_status": "200",
+                    }
+
+                    # Prepare files
+                    files = {"file": (file_name, open(file_path, "rb"), content_type)}
+
+                    print(f"📤 正在上传文件: {file_name}")
+
+                    # Upload file
+                    response = http.post(
+                        upload_token["host"], data=form_data, files=files
+                    )
+
+                    if response.status_code != 200:
+                        print(f"❌ 上传失败 {file_name}: HTTP {response.status_code}")
+                        return False
+
+                    # Determine file type based on extension
+                    file_ext = os.path.splitext(file_path)[1].lower()
+                    is_image = file_ext in self.IMAGE_EXTENSIONS
+
+                    uploaded_files.append(
+                        {
+                            "fileKey": file_name,
+                            "fileType": "image" if is_image else "file",
+                            "dir": upload_token["dir"],
+                        }
+                    )
+
+                    print(f"🔍 获取下载链接: {file_name}")
+
+                    # Get download links for uploaded files
+                    url = "https://api.tongyi.com/dialog/downloadLink/batch"
+                    headers = self._get_base_headers()
+                    payload = {
+                        "fileKeys": [f["fileKey"] for f in uploaded_files],
+                        "fileType": (
+                            "image"
+                            if any(f["fileType"] == "image" for f in uploaded_files)
+                            else "file"
+                        ),
+                        "dir": upload_token["dir"],
+                    }
+
+                    response = http.post(url, headers=headers, json=payload)
+                    if response.status_code != 200:
+                        print(f"❌ 获取下载链接失败: HTTP {response.status_code}")
+                        return False
+
+                    result = response.json()
+                    if not result.get("success"):
+                        print(f"❌ 获取下载链接失败: {result.get('errorMsg')}")
+                        return False
+
+                    # Add files to chat
+                    self.uploaded_file_info = result.get("data", {}).get("results", [])
+                    for file_info in self.uploaded_file_info:
+                        print(f"🔍 添加文件到对话: {file_name}")
+                        add_url = "https://api.tongyi.com/assistant/api/chat/file/add"
+                        add_payload = {
+                            "workSource": "chat",
+                            "terminal": "web",
+                            "workCode": "0",
+                            "channel": "home",
+                            "workType": "file",
+                            "module": "uploadhistory",
+                            "workName": file_info["fileKey"],
+                            "workId": file_info["docId"],
+                            "workResourcePath": file_info["url"],
+                            "sessionId": "",
+                            "batchId": str(uuid.uuid4()).replace("-", "")[
+                                :32
+                            ],  # Generate random batchId
+                            "fileSize": os.path.getsize(file_path),
+                        }
+
+                        add_response = http.post(
+                            add_url, headers=headers, json=add_payload
+                        )
+                        if add_response.status_code != 200:
+                            print(
+                                f"❌ 添加文件到对话失败: HTTP {add_response.status_code}"
+                            )
+                            continue
+
+                        add_result = add_response.json()
+                        if not add_result.get("success"):
+                            print(
+                                f"❌ 添加文件到对话失败: {add_result.get('errorMsg')}"
+                            )
+                            continue
+
+                        file_info.update(add_result.get("data", {}))
+
+                    print(f"✅ 文件 {file_name} 上传成功")
+                    time.sleep(1)  # 短暂暂停以便用户看到成功状态
+
+                except Exception as e:
+                    print(f"❌ 上传文件 {file_name} 时出错: {str(e)}")
+                    return False
             return True
 
         except Exception as e:
@@ -467,6 +438,15 @@ class TongyiPlatform(BasePlatform):
         """
         return self.model_name
 
+    @classmethod
+    def platform_name(cls) -> str:
+        """Get platform name
+
+        Returns:
+            str: Platform name
+        """
+        return "tongyi"
+
     def delete_chat(self) -> bool:
         """Delete chat history
 
@@ -482,7 +462,7 @@ class TongyiPlatform(BasePlatform):
 
         try:
             response = while_success(
-                lambda: requests.post(url, headers=headers, json=payload), sleep_time=5
+                lambda: http.post(url, headers=headers, json=payload), sleep_time=5
             )
             if response.status_code != 200:
                 PrettyOutput.print(
@@ -499,6 +479,56 @@ class TongyiPlatform(BasePlatform):
             PrettyOutput.print(f"Error deleting chat: {str(e)}", OutputType.ERROR)
             return False
 
+    def save(self, file_path: str) -> bool:
+        """Save chat session to a file."""
+        if not self.session_id:
+            PrettyOutput.print("没有活动的会话可供保存", OutputType.WARNING)
+            return False
+
+        state = {
+            "session_id": self.session_id,
+            "request_id": self.request_id,
+            "msg_id": self.msg_id,
+            "model_name": self.model_name,
+            "uploaded_file_info": self.uploaded_file_info,
+            "system_message": self.system_message,
+            "first_chat": self.first_chat,
+        }
+
+        try:
+            with open(file_path, "w", encoding="utf-8") as f:
+                json.dump(state, f, ensure_ascii=False, indent=4)
+            self._saved = True
+            PrettyOutput.print(f"会话已成功保存到 {file_path}", OutputType.SUCCESS)
+            return True
+        except Exception as e:
+            PrettyOutput.print(f"保存会话失败: {str(e)}", OutputType.ERROR)
+            return False
+
+    def restore(self, file_path: str) -> bool:
+        """Restore chat session from a file."""
+        try:
+            with open(file_path, "r", encoding="utf-8") as f:
+                state = json.load(f)
+
+            self.session_id = state.get("session_id", "")
+            self.request_id = state.get("request_id", "")
+            self.msg_id = state.get("msg_id", "")
+            self.model_name = state.get("model_name", "")
+            self.uploaded_file_info = state.get("uploaded_file_info", [])
+            self.system_message = state.get("system_message", "")
+            self.first_chat = state.get("first_chat", True)
+            self._saved = True
+
+            PrettyOutput.print(f"从 {file_path} 成功恢复会话", OutputType.SUCCESS)
+            return True
+        except FileNotFoundError:
+            PrettyOutput.print(f"会话文件未找到: {file_path}", OutputType.ERROR)
+            return False
+        except Exception as e:
+            PrettyOutput.print(f"恢复会话失败: {str(e)}", OutputType.ERROR)
+            return False
+
     def set_system_prompt(self, message: str):
         """Set system message
 
@@ -527,3 +557,32 @@ class TongyiPlatform(BasePlatform):
             bool: True if web is supported, False otherwise
         """
         return True
+
+    @classmethod
+    def get_required_env_keys(cls) -> List[str]:
+        """
+        获取通义平台所需的环境变量键列表
+
+        返回:
+            List[str]: 环境变量键的列表
+        """
+        return ["TONGYI_COOKIES"]
+
+    @classmethod
+    def get_env_config_guide(cls) -> Dict[str, str]:
+        """
+        获取环境变量配置指导
+
+        返回:
+            Dict[str, str]: 环境变量名到配置指导的映射
+        """
+        return {
+            "TONGYI_COOKIES": (
+                "1. 登录通义千问网页版: https://tongyi.aliyun.com/\n"
+                "2. 打开浏览器开发者工具 (F12)\n"
+                '3. 切换到"网络"(Network)标签页\n'
+                "4. 刷新页面或发送一条消息\n"
+                "5. 找到 conversation 请求或任意发往 api.tongyi.com 的请求\n"
+                '6. 在"请求标头"中复制完整的 Cookie 值'
+            )
+        }
