@@ -20,12 +20,13 @@ class Tool:
         self.description = description
         self.parameters = parameters
         self.func = func
+
     def to_dict(self) -> Dict:
         """将工具对象转换为字典格式，主要用于序列化"""
         return {
             "name": self.name,
             "description": self.description,
-            "parameters": json.dumps(self.parameters, ensure_ascii=False)
+            "parameters": json.dumps(self.parameters, ensure_ascii=False),
         }
 
     def execute(self, arguments: Dict) -> Dict[str, Any]:
@@ -38,4 +39,11 @@ class Tool:
         返回:
             Dict[str, Any]: 工具执行结果
         """
-        return self.func(arguments)
\ No newline at end of file
+        try:
+            return self.func(arguments)
+        except Exception as e:
+            return {
+                "success": False,
+                "stderr": f"工具 {self.name} 执行失败: {str(e)}",
+                "stdout": "",
+            }
