@@ -7,19 +7,18 @@ import tempfile
 from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional, Protocol, Tuple
 
-from numpy import place
 import yaml
 
 from jarvis.jarvis_mcp import McpClient
 from jarvis.jarvis_mcp.sse_mcp_client import SSEMcpClient
 from jarvis.jarvis_mcp.stdio_mcp_client import StdioMcpClient
 from jarvis.jarvis_mcp.streamable_mcp_client import StreamableMcpClient
-from jarvis.jarvis_platform.registry import PlatformRegistry
 from jarvis.jarvis_tools.base import Tool
-from jarvis.jarvis_utils.config import get_data_dir
+from jarvis.jarvis_utils.config import get_data_dir, get_tool_load_dirs
+from jarvis.jarvis_utils.input import user_confirm
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
 from jarvis.jarvis_utils.tag import ct, ot
-from jarvis.jarvis_utils.utils import is_context_overflow
+from jarvis.jarvis_utils.utils import is_context_overflow, daily_check_git_updates
 
 tool_call_help = f"""
 <tool_system_guide>
@@ -109,23 +108,26 @@ arguments:
 
 class OutputHandlerProtocol(Protocol):
     def name(self) -> str: ...
+
     def can_handle(self, response: str) -> bool: ...
+
     def prompt(self) -> str: ...
+
     def handle(self, response: str, agent: Any) -> Tuple[bool, Any]: ...
 
-class ToolRegistry(OutputHandlerProtocol):
 
+class ToolRegistry(OutputHandlerProtocol):
     def name(self) -> str:
         return "TOOL_CALL"
 
     def can_handle(self, response: str) -> bool:
-        return ToolRegistry._has_tool_calls_block(response)
+        return ot("TOOL_CALL") in response
 
     def prompt(self) -> str:
         """加载工具"""
         tools = self.get_all_tools()
         if tools:
-            tools_prompt = "<tools_section>\n"
+            tools_prompt = f"<tools_section>\n"
             tools_prompt += "  <header>## 可用工具:</header>\n"
             tools_prompt += "  <tools_list>\n"
             for tool in tools:
@@ -166,11 +168,21 @@ class ToolRegistry(OutputHandlerProtocol):
             return tools_prompt
         return ""
 
-    def handle(self, response: str, agent: Any) -> Tuple[bool, Any]:
-        tool_call, err_msg = self._extract_tool_calls(response)
-        if err_msg:
-            return False, err_msg
-        return False, self.handle_tool_calls(tool_call, agent)
+    def handle(self, response: str, agent_: Any) -> Tuple[bool, Any]:
+        try:
+            tool_call, err_msg = self._extract_tool_calls(response)
+            if err_msg:
+                return False, err_msg
+            return False, self.handle_tool_calls(tool_call, agent_)
+        except Exception as e:
+            PrettyOutput.print(f"工具调用处理失败: {str(e)}", OutputType.ERROR)
+            from jarvis.jarvis_agent import Agent
+
+            agent: Agent = agent_
+            return (
+                False,
+                f"工具调用处理失败: {str(e)}\n\n{agent.get_tool_usage_prompt()}",
+            )
 
     def __init__(self) -> None:
         """初始化工具注册表"""
@@ -179,32 +191,46 @@ class ToolRegistry(OutputHandlerProtocol):
         self._load_builtin_tools()
         self._load_external_tools()
         self._load_mcp_tools()
+        # 应用工具配置组过滤
+        self._apply_tool_config_filter()
 
     def _get_tool_stats(self) -> Dict[str, int]:
         """从数据目录获取工具调用统计"""
-        stats_file = Path(get_data_dir()) / "tool_stat.yaml"
-        if stats_file.exists():
-            try:
-                with open(stats_file, "r", encoding="utf-8") as f:
-                    return yaml.safe_load(f) or {}
-            except Exception as e:
-                PrettyOutput.print(
-                    f"加载工具调用统计失败: {str(e)}", OutputType.WARNING
-                )
-        return {}
+        from jarvis.jarvis_stats.stats import StatsManager
+        from datetime import datetime, timedelta
+
+        # 获取所有工具的统计数据
+        tool_stats = {}
+        tools = self.get_all_tools()
+
+        # 获取所有历史数据（从很早的时间开始）
+        end_time = datetime.now()
+        start_time = datetime(2000, 1, 1)  # 使用一个足够早的时间
+
+        for tool in tools:
+            tool_name = tool["name"]
+            # 获取该工具的统计数据
+            stats_data = StatsManager.get_stats(
+                metric_name=tool_name,
+                start_time=start_time,
+                end_time=end_time,
+                tags={"group": "tool"},
+            )
+
+            # 计算总调用次数
+            if stats_data and "records" in stats_data:
+                total_count = sum(record["value"] for record in stats_data["records"])
+                tool_stats[tool_name] = int(total_count)
+            else:
+                tool_stats[tool_name] = 0
+
+        return tool_stats
 
     def _update_tool_stats(self, name: str) -> None:
         """更新工具调用统计"""
-        stats = self._get_tool_stats()
-        stats[name] = stats.get(name, 0) + 1
-        stats_file = Path(get_data_dir()) / "tool_stat.yaml"
-        try:
-            with open(stats_file, "w", encoding="utf-8") as f:
-                yaml.safe_dump(stats, f, allow_unicode=True)
-        except Exception as e:
-            PrettyOutput.print(
-                f"保存工具调用统计失败: {str(e)}", OutputType.WARNING
-            )
+        from jarvis.jarvis_stats.stats import StatsManager
+
+        StatsManager.increment(name, group="tool")
 
     def use_tools(self, name: List[str]) -> None:
         """使用指定工具
@@ -218,7 +244,11 @@ class ToolRegistry(OutputHandlerProtocol):
                 f"工具 {missing_tools} 不存在，可用的工具有: {', '.join(self.tools.keys())}",
                 OutputType.WARNING,
             )
-        self.tools = {tool_name: self.tools[tool_name] for tool_name in name if tool_name in self.tools}
+        self.tools = {
+            tool_name: self.tools[tool_name]
+            for tool_name in name
+            if tool_name in self.tools
+        }
 
     def dont_use_tools(self, names: List[str]) -> None:
         """从注册表中移除指定工具
@@ -230,10 +260,40 @@ class ToolRegistry(OutputHandlerProtocol):
             name: tool for name, tool in self.tools.items() if name not in names
         }
 
+    def _apply_tool_config_filter(self) -> None:
+        """应用工具配置组的过滤规则"""
+        from jarvis.jarvis_utils.config import get_tool_use_list, get_tool_dont_use_list
+
+        use_list = get_tool_use_list()
+        dont_use_list = get_tool_dont_use_list()
+
+        # 如果配置了 use 列表，只保留列表中的工具
+        if use_list:
+            filtered_tools = {}
+            for tool_name in use_list:
+                if tool_name in self.tools:
+                    filtered_tools[tool_name] = self.tools[tool_name]
+                else:
+                    PrettyOutput.print(
+                        f"警告: 配置的工具 '{tool_name}' 不存在",
+                        OutputType.WARNING,
+                    )
+            self.tools = filtered_tools
+
+        # 如果配置了 dont_use 列表，排除列表中的工具
+        if dont_use_list:
+            for tool_name in dont_use_list:
+                if tool_name in self.tools:
+                    del self.tools[tool_name]
+                    PrettyOutput.print(
+                        f"已排除工具: {tool_name}",
+                        OutputType.INFO,
+                    )
+
     def _load_mcp_tools(self) -> None:
         """加载MCP工具，优先从配置获取，其次从目录扫描"""
         from jarvis.jarvis_utils.config import get_mcp_config
-        
+
         # 优先从配置获取MCP工具配置
         mcp_configs = get_mcp_config()
         if mcp_configs:
@@ -249,7 +309,7 @@ class ToolRegistry(OutputHandlerProtocol):
         # 添加警告信息
         PrettyOutput.print(
             "警告: 从文件目录加载MCP工具的方式将在未来版本中废弃，请尽快迁移到JARVIS_MCP配置方式",
-            OutputType.WARNING
+            OutputType.WARNING,
         )
 
         # 遍历目录中的所有.yaml文件
@@ -275,18 +335,49 @@ class ToolRegistry(OutputHandlerProtocol):
             self.register_tool_by_file(str(file_path))
 
     def _load_external_tools(self) -> None:
-        """从jarvis_data/tools加载外部工具"""
-        external_tools_dir = Path(get_data_dir()) / "tools"
-        if not external_tools_dir.exists():
-            return
+        """从jarvis_data/tools和配置的目录加载外部工具"""
+        from jarvis.jarvis_utils.config import get_central_tool_repo
 
-        # 遍历目录中的所有.py文件
-        for file_path in external_tools_dir.glob("*.py"):
-            # 跳过__init__.py
-            if file_path.name == "__init__.py":
+        tool_dirs = [str(Path(get_data_dir()) / "tools")] + get_tool_load_dirs()
+
+        # 如果配置了中心工具仓库，将其添加到加载路径
+        central_repo = get_central_tool_repo()
+        if central_repo:
+            # 中心工具仓库存储在数据目录下的特定位置
+            central_repo_path = os.path.join(get_data_dir(), "central_tool_repo")
+            tool_dirs.append(central_repo_path)
+
+            # 确保中心工具仓库被克隆/更新
+            if not os.path.exists(central_repo_path):
+                try:
+                    import subprocess
+
+                    PrettyOutput.print(
+                        f"正在克隆中心工具仓库: {central_repo}", OutputType.INFO
+                    )
+                    subprocess.run(
+                        ["git", "clone", central_repo, central_repo_path], check=True
+                    )
+                except Exception as e:
+                    PrettyOutput.print(
+                        f"克隆中心工具仓库失败: {str(e)}", OutputType.ERROR
+                    )
+
+        # --- 全局每日更新检查 ---
+        daily_check_git_updates(tool_dirs, "tools")
+
+        for tool_dir in tool_dirs:
+            p_tool_dir = Path(tool_dir)
+            if not p_tool_dir.exists() or not p_tool_dir.is_dir():
                 continue
 
-            self.register_tool_by_file(str(file_path))
+            # 遍历目录中的所有.py文件
+            for file_path in p_tool_dir.glob("*.py"):
+                # 跳过__init__.py
+                if file_path.name == "__init__.py":
+                    continue
+
+                self.register_tool_by_file(str(file_path))
 
     def register_mcp_tool_by_config(self, config: Dict[str, Any]) -> bool:
         """从配置字典加载并注册工具
@@ -299,12 +390,17 @@ class ToolRegistry(OutputHandlerProtocol):
         """
         try:
             if "type" not in config:
-                PrettyOutput.print(f"配置{config.get('name', '')}缺少type字段", OutputType.WARNING)
+                PrettyOutput.print(
+                    f"配置{config.get('name', '')}缺少type字段", OutputType.WARNING
+                )
                 return False
 
             # 检查enable标志
             if not config.get("enable", True):
-                PrettyOutput.print(f"MCP配置{config.get('name', '')}已禁用(enable=false)，跳过注册", OutputType.INFO)
+                PrettyOutput.print(
+                    f"MCP配置{config.get('name', '')}已禁用(enable=false)，跳过注册",
+                    OutputType.INFO,
+                )
                 return False
 
             name = config.get("name", "mcp")
@@ -317,7 +413,8 @@ class ToolRegistry(OutputHandlerProtocol):
                     args.pop("want", None)
                     ret = client.get_resource_list()
                     PrettyOutput.print(
-                        f"MCP {name} 资源列表:\n{yaml.safe_dump(ret, allow_unicode=True)}", OutputType.TOOL
+                        f"MCP {name} 资源列表:\n{yaml.safe_dump(ret, allow_unicode=True)}",
+                        OutputType.TOOL,
                     )
                     return {
                         "success": True,
@@ -340,7 +437,8 @@ class ToolRegistry(OutputHandlerProtocol):
                         }
                     ret = client.get_resource(args["uri"])
                     PrettyOutput.print(
-                        f"MCP {name} 获取资源:\n{yaml.safe_dump(ret, allow_unicode=True)}", OutputType.TOOL
+                        f"MCP {name} 获取资源:\n{yaml.safe_dump(ret, allow_unicode=True)}",
+                        OutputType.TOOL,
                     )
                     return ret
 
@@ -362,34 +460,49 @@ class ToolRegistry(OutputHandlerProtocol):
 
             if config["type"] == "stdio":
                 if "command" not in config:
-                    PrettyOutput.print(f"配置{config.get('name', '')}缺少command字段", OutputType.WARNING)
+                    PrettyOutput.print(
+                        f"配置{config.get('name', '')}缺少command字段",
+                        OutputType.WARNING,
+                    )
                     return False
             elif config["type"] == "sse":
                 if "base_url" not in config:
-                    PrettyOutput.print(f"配置{config.get('name', '')}缺少base_url字段", OutputType.WARNING)
+                    PrettyOutput.print(
+                        f"配置{config.get('name', '')}缺少base_url字段",
+                        OutputType.WARNING,
+                    )
                     return False
             elif config["type"] == "streamable":
                 if "base_url" not in config:
-                    PrettyOutput.print(f"配置{config.get('name', '')}缺少base_url字段", OutputType.WARNING)
+                    PrettyOutput.print(
+                        f"配置{config.get('name', '')}缺少base_url字段",
+                        OutputType.WARNING,
+                    )
                     return False
             else:
-                PrettyOutput.print(f"不支持的MCP客户端类型: {config['type']}", OutputType.WARNING)
+                PrettyOutput.print(
+                    f"不支持的MCP客户端类型: {config['type']}", OutputType.WARNING
+                )
                 return False
 
             # 创建MCP客户端
+            mcp_client: McpClient
             if config["type"] == "stdio":
-                mcp_client: McpClient = StdioMcpClient(config)
+                mcp_client = StdioMcpClient(config)
             elif config["type"] == "sse":
-                mcp_client: McpClient = SSEMcpClient(config)
+                mcp_client = SSEMcpClient(config)
             elif config["type"] == "streamable":
-                mcp_client: McpClient = StreamableMcpClient(config)
+                mcp_client = StreamableMcpClient(config)
             else:
                 raise ValueError(f"不支持的MCP客户端类型: {config['type']}")
 
             # 获取工具信息
             tools = mcp_client.get_tool_list()
             if not tools:
-                PrettyOutput.print(f"从配置{config.get('name', '')}获取工具列表失败", OutputType.WARNING)
+                PrettyOutput.print(
+                    f"从配置{config.get('name', '')}获取工具列表失败",
+                    OutputType.WARNING,
+                )
                 return False
 
             # 注册每个工具
@@ -427,7 +540,9 @@ class ToolRegistry(OutputHandlerProtocol):
             return True
 
         except Exception as e:
-            PrettyOutput.print(f"MCP配置{config.get('name', '')}加载失败: {str(e)}", OutputType.WARNING)
+            PrettyOutput.print(
+                f"MCP配置{config.get('name', '')}加载失败: {str(e)}", OutputType.WARNING
+            )
             return False
 
     def register_tool_by_file(self, file_path: str) -> bool:
@@ -467,7 +582,6 @@ class ToolRegistry(OutputHandlerProtocol):
                         and hasattr(item, "execute")
                         and item.name == module_name
                     ):
-
                         if hasattr(item, "check"):
                             if not item.check():
                                 continue
@@ -525,28 +639,63 @@ class ToolRegistry(OutputHandlerProtocol):
         data = re.findall(
             ot("TOOL_CALL") + r"(.*?)" + ct("TOOL_CALL"), content, re.DOTALL
         )
+        if not data:
+            # can_handle 确保 ot("TOOL_CALL") 在内容中。
+            # 如果数据为空，则表示 ct("TOOL_CALL") 可能丢失。
+            if ot("TOOL_CALL") in content and ct("TOOL_CALL") not in content:
+                # 尝试通过附加结束标签来修复它
+                fixed_content = content.strip() + f"\n{ct('TOOL_CALL')}"
+
+                # 再次提取，并检查YAML是否有效
+                temp_data = re.findall(
+                    ot("TOOL_CALL") + r"(.*?)" + ct("TOOL_CALL"),
+                    fixed_content,
+                    re.DOTALL,
+                )
+
+                if temp_data:
+                    try:
+                        yaml.safe_load(temp_data[0])  # Check if valid YAML
+
+                        # Ask user for confirmation
+                        PrettyOutput.print(
+                            f"检测到缺失的 {ct('TOOL_CALL')} 标签，已自动修复。修复后的内容如下:",
+                            OutputType.INFO,
+                        )
+                        PrettyOutput.print(fixed_content, OutputType.TOOL)
+                        data = temp_data
+                    except (yaml.YAMLError, EOFError, KeyboardInterrupt):
+                        # Even after fixing, it's not valid YAML, or user cancelled.
+                        # Fall through to the original error.
+                        pass
+
+            if not data:
+                return (
+                    {},
+                    f"只有{ot('TOOL_CALL')}标签，未找到{ct('TOOL_CALL')}标签，调用格式错误，请检查工具调用格式。\n{tool_call_help}",
+                )
         ret = []
         for item in data:
             try:
                 msg = yaml.safe_load(item)
-                if "name" in msg and "arguments" in msg and "want" in msg:
-                    ret.append(msg)
-                else:
-                    return (
-                        {},
-                        f"""工具调用格式错误，请检查工具调用格式（缺少name、arguments、want字段）。
-
-                    {tool_call_help}""",
-                    )
             except Exception as e:
                 return (
                     {},
-                    f"""工具调用格式错误，请检查工具调用格式。
-
+                    f"""yaml 解析失败，请检查工具调用格式。
                     {e}
 
                 {tool_call_help}""",
                 )
+
+            if "name" in msg and "arguments" in msg and "want" in msg:
+                ret.append(msg)
+            else:
+                return (
+                    {},
+                    f"""工具调用格式错误，请检查工具调用格式（缺少name、arguments、want字段）。
+
+                {tool_call_help}""",
+                )
         if len(ret) > 1:
             return {}, "检测到多个工具调用，请一次只处理一个工具调用。"
         return ret[0] if ret else {}, ""
@@ -566,6 +715,10 @@ class ToolRegistry(OutputHandlerProtocol):
             parameters: 工具参数定义
             func: 工具执行函数
         """
+        if name in self.tools:
+            PrettyOutput.print(
+                f"警告: 工具 '{name}' 已存在，将被覆盖", OutputType.WARNING
+            )
         self.tools[name] = Tool(name, description, parameters, func)
 
     def get_tool(self, name: str) -> Optional[Tool]:
@@ -604,10 +757,10 @@ class ToolRegistry(OutputHandlerProtocol):
                 "stderr": f"工具 {name} 不存在，可用的工具有: {', '.join(self.tools.keys())}",
                 "stdout": "",
             }
-        
+
         # 更新工具调用统计
         self._update_tool_stats(name)
-        
+
         return tool.execute(arguments)
 
     def _format_tool_output(self, stdout: str, stderr: str) -> str:
@@ -622,24 +775,26 @@ class ToolRegistry(OutputHandlerProtocol):
         """
         output_parts = []
         if stdout:
-            output_parts.append(f"<output>\n{stdout}\n</output>")
+            output_parts.append(f"<stdout>\n{stdout}\n</stdout>")
         if stderr:
-            output_parts.append(f"<error>\n{stderr}\n</error>")
+            output_parts.append(f"<stderr>\n{stderr}\n</stderr>")
         output = "\n\n".join(output_parts)
         return "<无输出和错误>" if not output else output
 
     def _truncate_output(self, output: str) -> str:
         """截断过长的输出内容
-        
+
         参数:
             output: 要截断的输出内容
-            
+
         返回:
             截断后的内容，如果内容不超过60行则返回原内容
         """
         if len(output.splitlines()) > 60:
             lines = output.splitlines()
-            return '\n'.join(lines[:30] + ['\n...内容太长，已截取前后30行...\n'] + lines[-30:])
+            return "\n".join(
+                lines[:30] + ["\n...内容太长，已截取前后30行...\n"] + lines[-30:]
+            )
         return output
 
     def handle_tool_calls(self, tool_call: Dict[str, Any], agent: Any) -> str:
@@ -650,7 +805,8 @@ class ToolRegistry(OutputHandlerProtocol):
             args["agent"] = agent
 
             from jarvis.jarvis_agent import Agent
-            agent_instance: Agent = agent 
+
+            agent_instance: Agent = agent
 
             if isinstance(args, str):
                 try:
@@ -670,20 +826,30 @@ class ToolRegistry(OutputHandlerProtocol):
             )
 
             # 检查内容是否过大
-            is_large_content = is_context_overflow(output)
-            
+            model_group = None
+            if agent_instance.model:
+                model_group = agent_instance.model.model_group
+            is_large_content = is_context_overflow(output, model_group)
+
             if is_large_content:
                 # 创建临时文件
-                with tempfile.NamedTemporaryFile(mode="w", suffix=".txt", delete=False) as tmp_file:
+                with tempfile.NamedTemporaryFile(
+                    mode="w", suffix=".txt", delete=False
+                ) as tmp_file:
                     output_file = tmp_file.name
                     tmp_file.write(output)
                     tmp_file.flush()
-                
+
                 try:
-                    if agent_instance.model and agent_instance.model.support_upload_files():
+                    if (
+                        agent_instance.model
+                        and agent_instance.model.support_upload_files()
+                    ):
                         summary = agent_instance.generate_summary()
                         agent_instance.clear_history()
-                        upload_success = agent_instance.model.upload_files([output_file])
+                        upload_success = agent_instance.model.upload_files(
+                            [output_file]
+                        )
                         if upload_success:
                             # 删除args的agent键
                             args.pop("agent", None)
@@ -714,4 +880,3 @@ class ToolRegistry(OutputHandlerProtocol):
         except Exception as e:
             PrettyOutput.print(f"工具执行失败：{str(e)}", OutputType.ERROR)
             return f"工具调用失败: {str(e)}"
-
