@@ -16,7 +16,7 @@ import subprocess
 import sys
 from typing import Any, Dict, List, Set, Tuple
 
-from jarvis.jarvis_utils.config import is_confirm_before_apply_patch
+from jarvis.jarvis_utils.config import get_data_dir, is_confirm_before_apply_patch
 from jarvis.jarvis_utils.output import OutputType, PrettyOutput
 from jarvis.jarvis_utils.input import user_confirm
 
@@ -282,7 +282,7 @@ def get_latest_commit_hash() -> str:
         return ""
 
 
-def get_modified_line_ranges() -> Dict[str, Tuple[int, int]]:
+def get_modified_line_ranges() -> Dict[str, List[Tuple[int, int]]]:
     """从Git差异中获取所有更改文件的修改行范围
 
     返回：
@@ -293,7 +293,7 @@ def get_modified_line_ranges() -> Dict[str, Tuple[int, int]]:
     diff_output = os.popen("git show").read()
 
     # 解析差异以获取修改的文件及其行范围
-    result = {}
+    result: Dict[str, List[Tuple[int, int]]] = {}
     current_file = None
 
     for line in diff_output.splitlines():
@@ -309,7 +309,9 @@ def get_modified_line_ranges() -> Dict[str, Tuple[int, int]]:
             start_line = int(range_match.group(1))  # 保持从1开始
             line_count = int(range_match.group(2)) if range_match.group(2) else 1
             end_line = start_line + line_count - 1
-            result[current_file] = (start_line, end_line)
+            if current_file not in result:
+                result[current_file] = []
+            result[current_file].append((start_line, end_line))
 
     return result
 
@@ -339,25 +341,21 @@ def check_and_update_git_repo(repo_path: str) -> bool:
     返回:
         bool: 是否执行了更新
     """
+    # 检查上次检查日期
+    last_check_file = os.path.join(get_data_dir(), "last_git_check")
+    today_str = datetime.date.today().strftime("%Y-%m-%d")
+    if os.path.exists(last_check_file):
+        with open(last_check_file, "r") as f:
+            last_check_date = f.read().strip()
+        if last_check_date == today_str:
+            return False
+
     curr_dir = os.path.abspath(os.getcwd())
     git_root = find_git_root_and_cd(repo_path)
     if git_root is None:
         return False
 
     try:
-        # 检查最新提交时间是否为今天
-        commit_date_result = subprocess.run(
-            ["git", "log", "-1", "--format=%cd", "--date=short"],
-            cwd=git_root,
-            capture_output=True,
-            text=True,
-        )
-        if commit_date_result.returncode == 0:
-            commit_date = commit_date_result.stdout.strip()
-            today = datetime.date.today().strftime("%Y-%m-%d")
-            if commit_date == today:
-                return False
-
         # 检查是否有未提交的修改
         if has_uncommitted_changes():
             return False
@@ -418,8 +416,53 @@ def check_and_update_git_repo(repo_path: str) -> bool:
                     hasattr(sys, "base_prefix") and sys.base_prefix != sys.prefix
                 )
 
-                # 尝试普通安装
-                install_cmd = [sys.executable, "-m", "pip", "install", "-e", "."]
+                is_uv_env = False
+                if in_venv:
+                    # 检查是否在uv创建的虚拟环境内
+                    if sys.platform == "win32":
+                        uv_path = os.path.join(sys.prefix, "Scripts", "uv.exe")
+                    else:
+                        uv_path = os.path.join(sys.prefix, "bin", "uv")
+                    if os.path.exists(uv_path):
+                        is_uv_env = True
+
+                # 根据环境选择安装命令
+                # 检测是否安装了 RAG 特性
+                rag_installed = False
+                try:
+                    import langchain  # noqa
+
+                    rag_installed = True
+                except ImportError:
+                    pass
+
+                # 根据环境和 RAG 特性选择安装命令
+                if rag_installed:
+                    if is_uv_env:
+                        install_cmd = ["uv", "pip", "install", "-e", ".[rag]"]
+                    else:
+                        install_cmd = [
+                            sys.executable,
+                            "-m",
+                            "pip",
+                            "install",
+                            "-e",
+                            ".[rag]",
+                        ]
+                else:
+                    if is_uv_env:
+                        install_cmd = ["uv", "pip", "install", "-e", "."]
+                    else:
+                        install_cmd = [
+                            sys.executable,
+                            "-m",
+                            "pip",
+                            "install",
+                            "-e",
+                            ".",
+                        ]
+
+                # 尝试安装
                 result = subprocess.run(
                     install_cmd, cwd=git_root, capture_output=True, text=True
                 )
@@ -454,6 +497,9 @@ def check_and_update_git_repo(repo_path: str) -> bool:
                     f"安装过程中发生意外错误: {str(e)}", OutputType.ERROR
                 )
                 return False
+        # 更新检查日期文件
+        with open(last_check_file, "w") as f:
+            f.write(today_str)
         return False
     except Exception as e:
         PrettyOutput.print(f"Git仓库更新检查失败: {e}", OutputType.WARNING)
@@ -534,17 +580,19 @@ def get_recent_commits_with_files() -> List[Dict[str, Any]]:
             ],
             capture_output=True,
             text=True,
+            encoding="utf-8",
+            errors="replace",
         )
-        if result.returncode != 0:
+        if result.returncode != 0 or result.stdout is None:
             return []
 
         # 解析提交信息
-        commits = []
+        commits: List[Dict[str, Any]] = []
         lines = result.stdout.splitlines()
         for i in range(0, len(lines), 4):
             if i + 3 >= len(lines):
                 break
-            commit = {
+            commit: Dict[str, Any] = {
                 "hash": lines[i],
                 "message": lines[i + 1],
                 "author": lines[i + 2],
