@@ -10,7 +10,7 @@
 """
 from datetime import datetime
 from enum import Enum
-from typing import Optional, Tuple
+from typing import Dict, Optional, Tuple, Any
 
 from pygments.lexers import guess_lexer
 from pygments.util import ClassNotFound
@@ -131,7 +131,7 @@ class PrettyOutput:
         """
         try:
             lexer = guess_lexer(text)
-            detected_lang = lexer.name
+            detected_lang = lexer.name  # type: ignore[attr-defined]
             return PrettyOutput._lang_map.get(detected_lang, default_lang)
         except (ClassNotFound, Exception):
             return default_lang
@@ -175,7 +175,7 @@ class PrettyOutput:
             lang: 语法高亮的语言
             traceback: 是否显示错误的回溯信息
         """
-        styles = {
+        styles: Dict[OutputType, Dict[str, Any]] = {
             OutputType.SYSTEM: dict(bgcolor="#1e2b3c"),
             OutputType.CODE: dict(bgcolor="#1c2b1c"),
             OutputType.RESULT: dict(bgcolor="#1c1c2b"),
@@ -204,7 +204,7 @@ class PrettyOutput:
                 color="red", frame=True, bgcolor="#2b1c1c", meta={"icon": "❌"}
             ),
             OutputType.INFO: RichStyle(
-                color="gold1", frame=True, bgcolor="#2b2b1c", meta={"icon": "ℹ️"}
+                color="bright_cyan", frame=True, bgcolor="#2b2b1c", meta={"icon": "ℹ️"}
             ),
             OutputType.PLANNING: RichStyle(
                 color="purple",
